@@ -2,7 +2,7 @@ from invenio_records.api import Record
 from oarepo_validate import SchemaKeepingRecordMixin, MarshmallowValidatedRecordMixin
 
 from .constants import DATASETS_ALLOWED_SCHEMAS, DATASETS_PREFERRED_SCHEMA
-from .marshmallow import DatasetMetadataSchemaV1
+from .marshmallow import DataSetMetadataSchemaV3
 from oarepo_invenio_model import InheritedSchemaRecordMixin
 
 
@@ -35,4 +35,4 @@ class DatasetBaseRecord(SchemaKeepingRecordMixin,
                         Record):
     ALLOWED_SCHEMAS = DATASETS_ALLOWED_SCHEMAS
     PREFERRED_SCHEMA = DATASETS_PREFERRED_SCHEMA
-    MARSHMALLOW_SCHEMA = DatasetMetadataSchemaV1
+    MARSHMALLOW_SCHEMA = DataSetMetadataSchemaV3
